[−][src]Enum ca_rules::ParseRuleError
Errors that can be returned when parsing rule strings.
Variants
Missing(char)Missing an expected char
Missing an expected number
Unexpected(char)An unexpected char
Extra unparsed junk at the end of the rule string
Number of states less than 2 in Generations rule
Not a MAP rule
An error occurs when decoding the base64 string
Invalid length for MAP rule
Generations number overflow for Generations rule